#!/usr/bin/perl
#
# CalendarScript Debugger
#
# This script will help you debug problems that might occur when trying to
# setup the CalendarScript application

# BASE_DIR = "/path/";

# 
# NO NEED TO CHANGE ANYTHING BELOW HERE!

$|=1;
print "Content-type: text/html\n\n";
print "<HTML><HEAD><TITLE>CalendarScript Debugger</TITLE></HEAD>\n";
print "<BODY>\n";
print "<B><U>CalendarScript Debugger</U></B><BR><BR>\n";

sub exitNow { 
	print "<B>Once this problem is fixed, please re-run this debugger to check for any further errors!</B>";
	print "</BODY></HTML>\n";
	exit(0);
	}

# Check to see if the Path is available
# -------------------------------------
if ($BASE_DIR ne "") { $BASE_DIR =~ s|([^/])$|$1/|; }
else {
	my ($path) =  $ENV{'PATH_TRANSLATED'} || $ENV{'SCRIPT_FILENAME'};
	unless ($path) {
		$path = $0;
		$path =~ s|\\|/|g;
		$path =~ s|^[^/]*||;
		$path =~ s|[^/]*$||;
		$path .= "calendarscript/";
		print <<"END";
Your server doesn't supply CalendarScript with enough information for it to run correctly.
<BR><BR>
The program uses either the PATH_TRANSLATED or the SCRIPT_FILENAME environment variables to find out the local filesystem path of the
script itself, so it can then find its supporting files. Most web servers provide this information to CGI scripts, but yours does not.
<BR><BR>
You will need to edit the two script files - calendar.pl (or .cgi) and calendar_admin.pl (or .cgi) - and manually enter the 
filesystem path where the script is located.
<BR><BR>
You will also need to make the same change to this debug.pl (or .cgi) script in order to continue using it to debug any possible problems.
<BR><BR>
Information on how to do this can be found in the <A HREF="http://www.calendarscript.com/documentation/4.html">CalendarScript Documentation</A> 
under the problem which starts "PROBLEM: Your browser displays the message..."
<BR><BR>
If you do not know what path to use for this, the following is a suggestion. This is the best guess that this program can make given 
based on the information it has. It is not guaranteed to be correct on all systems, but might help:
<BR><BR>
<tt>Suggested Path = <span style="background-color:yellow;">$path</span></tt>
<BR><BR>
For more information, see the documentation or visit the <A HREF="http://www.CalendarScript.com/support/forum/Ultimate.cgi">Support Forum</A>
<BR><BR>
END
		&exitNow();
		}
	$path =~ s|[^/\\]*$||;
	$path =~ s|([^/])$|$1/|;
	$BASE_DIR = $path . "calendarscript/";
	}

# Check to make sure that files exist and have the correct permissions
# --------------------------------------------------------------------
while ($line = <DATA>) {
	chomp($line);
	push(@filecheck,$line);
	}
foreach $line (@filecheck) {
	my ($fileproblem) = {};
	($perm,$file) = split(/\t/,$line);
	$file = $BASE_DIR . $file;
	unless (-e $file) {
		$fileproblem->{filename} = $file;
		$fileproblem->{doesntexist} = 1;
		}
	if ($perm =~ /r/ && -e $file && !-r $file) {
		$fileproblem->{filename} = $file;
		$fileproblem->{noread} = 1;
		}
	if ($perm =~ /w/ && -e $file && !-w $file) {
		$fileproblem->{filename} = $file;
		$fileproblem->{nowrite} = 1;
		}
	if (-e $file && -t $file) {
		$fileproblem->{filename} = $file;
		$fileproblem->{notascii} = 1;
		}
	if ($fileproblem->{filename} ne "") {
		push(@fileproblems,$fileproblem);
		}
	}
if ($#fileproblems >= 0) {
	print <<"END";
There were problems detected with the files needed by CalendarScript. These problems may be caused by one of the following:
<UL>
	<LI>The \$BASE_DIR path is incorrect
	<LI>The files are not in the correct location
	<LI>The files were not FTP'ed in ASCII mode
	<LI>The files were not given the correct permissions using CHMOD
</UL>
The files with problems are listed below.
<BR><BR>
<TABLE BORDER="1">
<TR><TH>Problem</TH><TH>File</TH></TR>
END
	foreach $fileproblem (@fileproblems) {
		print "<TR><TD VALIGN=\"top\" ALIGN=\"left\">";
		if ($fileproblem->{doesntexist}) {
			print "&#149;The file does not exist<BR>";
			}
		if ($fileproblem->{noread}) {
			print "&#149;No READ access<BR>";
			}
		if ($fileproblem->{nowrite}) {
			print "&#149;No WRITE access<BR>";
			}
		if ($fileproblem->{notascii}) {
			print "&#149;The file was not transferred in ASCII mode<BR>";
			}
		print "</TD><TD VALIGN='top' ALIGN='left'>$fileproblem->{filename}</TD></TR>\n";
		}
	print "</TABLE>";
	&exitNow();
	}

# Check to make sure that the Session ID generation works correctly
# -----------------------------------------------------------------
$id = abs(($$%1000) * time);
unless ($id =~ /^\d{3,}$/) {
print <<"END";
There is a problem with generation a unique session ID for cookies.
<BR><BR>
The unique ID that was generated is: <tt>$id</tt>
<BR><BR>
Please report this using the <A HREF="http://www.CalendarScript.com/support/forum/Ultimate.cgi">Support Forum</A> so that this
problem can be fixed and systems with your configuration may be supported.
END
	&exitNow();
	}

# Check to make sure that libraries can be included
# -------------------------------------------------
unshift(@INC,$BASE_DIR."lib");
sub includefile { 
	my $file = shift;
	eval("require '${file}';");
	$error = $@;
	if ($error) {
		push(@includeerrors, {'filename'=>$file, 'error'=>$error} );
		}
	}
&includefile('TimeLocal.inc');
&includefile("calendars.inc");
&includefile("CGISession.inc");
&includefile("User.pm");
&includefile("Date.inc");
&includefile("HTML.pm");
&includefile("Config.pm");
&includefile("flock.inc");
&includefile("permissions.inc");
&includefile("asp.inc");
&includefile("DBFile.pm");
&includefile("DBFileUtil.inc");
&includefile("Event.inc");
&includefile("SimpleDateFormat.pm");
&includefile("Copy.pm");
if ($#includeerrors >= 0) {
	print <<"END";
There was a problem using library modules. These are found in the calendarscript/lib directory. For some reason Perl cannot 
find these files in order to include them into the application. Please report this error to the 
<A HREF="http://www.CalendarScript.com/support/forum/Ultimate.cgi">Support Forum</A> so that it can be resolved.
<BR><BR>
The following is a list of the files which caused problems during import:
<TABLE BORDER="1">
<TR><TH>File</TH><TH>Error</TH></TR>
END
	foreach $error (@includeerrors) {
		print "<TR><TD VALIGN=top>$error->{filename}</TD><TD>$error->{error}</TD></TR>\n";
		}
	print "</TABLE>";
	&exitNow();
	}


# EVERYTHING LOOKS GOOD!
# ----------------------
print <<"END";
<B>Success!</B><BR>
<BR>
No problems were found with your installation.
<BR>
You should be able to run calendar and calendar_admin successfully!
</BODY>
</HTML>
END
exit(0);

__DATA__
rw	calendars.txt
rw	config.txt
rw	users.txt
rw	permissions.txt
rw	users.lock
rw	calendars.id
rw	users.id
rw	users.properties
rw	permissions.lock
rw	permissions.id
rw	permissions.properties
rw	config.txt.lock
r	ssi.txt
rw	calendars.properties
rw	calendars.lock
r	templates
rw	calendars
r	lib
rw	session
rw	calendars/_template
rw	calendars/default
rw	calendars/default/events.txt
rw	calendars/default/schedule.txt
rw	calendars/default/config.txt
rw	calendars/default/events.lock
rw	calendars/default/events.id
rw	calendars/default/schedule.properties
rw	calendars/default/schedule.lock
rw	calendars/default/schedule.id
rw	calendars/default/config.txt.lock
rw	calendars/default/events.properties
rw	calendars/_template/config.txt
rw	calendars/_template/config.txt.lock
rw	calendars/_template/events.id
rw	calendars/_template/events.lock
rw	calendars/_template/events.properties
rw	calendars/_template/events.txt
rw	calendars/_template/schedule.id
rw	calendars/_template/schedule.lock
rw	calendars/_template/schedule.properties
rw	calendars/_template/schedule.txt
r	lib/TimeLocal.inc
r	lib/calendars.inc
r	lib/CGISession.inc
r	lib/User.pm
r	lib/Date.inc
r	lib/HTML.pm
r	lib/Config.pm
r	lib/flock.inc
r	lib/permissions.inc
r	lib/asp.inc
r	lib/DBFile.pm
r	lib/DBFileUtil.inc
r	lib/Event.inc
r	lib/SimpleDateFormat.pm
r	lib/Copy.pm
r	templates/admin
r	templates/calendars
r	templates/admin/English
r	templates/admin/English/validations.js
r	templates/admin/English/_footer.html
r	templates/admin/English/_header.html
r	templates/admin/English/add_edit_event.html
r	templates/admin/English/add_edit_field.html
r	templates/admin/English/add_edit_user.html
r	templates/admin/English/feedback.html
r	templates/admin/English/approve.html
r	templates/admin/English/calendar_settings.html
r	templates/admin/English/setup1.html
r	templates/admin/English/change_password.html
r	templates/admin/English/setup2.html
r	templates/admin/English/setup_complete.html
r	templates/admin/English/customize_event_fields.html
r	templates/admin/English/customize_user_fields.html
r	templates/admin/English/dates.js
r	templates/admin/English/edit_delete_events.html
r	templates/admin/English/edit_delete_users.html
r	templates/admin/English/error.html
r	templates/admin/English/login.html
r	templates/admin/English/main.html
r	templates/admin/English/permissions.html
r	templates/admin/English/permissions_error.html
r	templates/admin/English/PopupWindow.js
r	templates/admin/English/manage_calendars.html
r	templates/admin/English/select_calendar.html
r	templates/admin/English/selectbox.js
r	templates/admin/English/styles.css
r	templates/admin/English/tabnext.js
r	templates/admin/English/template.html
r	templates/admin/English/util.js
r	templates/admin/English/_command_list.html
r	templates/admin/English/admin_interface.html
r	templates/admin/English/schedule_event_recurring.html
r	templates/admin/English/AnchorPosition.js
r	templates/admin/English/CalendarPopup.js
r	templates/admin/English/GetDate.js
r	templates/admin/English/ColorPicker.js
r	templates/admin/English/TimeValidations.js
r	templates/admin/English/messages.txt
r	templates/admin/English/add_edit_calendar.html
r	templates/admin/English/setup3.html
r	templates/admin/English/schedule_event_non_recur.html
r	templates/calendars/default
r	templates/calendars/oldstyle
r	templates/calendars/default/login.html
r	templates/calendars/default/error.html
r	templates/calendars/default/styles.pl
r	templates/calendars/default/default.html
r	templates/calendars/default/ssi.html
r	templates/calendars/oldstyle/login.html
r	templates/calendars/oldstyle/error.html
r	templates/calendars/oldstyle/_view.html
r	templates/calendars/oldstyle/day.html
r	templates/calendars/oldstyle/event_detail.html
r	templates/calendars/oldstyle/search.html
r	templates/calendars/oldstyle/default.html
r	templates/calendars/oldstyle/styles_scripts.html
r	templates/calendars/oldstyle/ssi.html
